window.Gleam.initSearch([{"doc":"fluoresce","title":"fluoresce","content":"# fluoresce\n\n[![Package Version](https://img.shields.io/hexpm/v/fluoresce)](https://hex.pm/packages/fluoresce)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/fluoresce/)\n\nAn algebraic effects framework for Gleam, with classical-logic types. \nThis is could also be seen as a library for the Continuation monad.\n\nThis is very Haskell-y, and is based directly on the paper &quot;The Duality of Abstraction,&quot; currently marked as a draft by Vikraman Choudhury but which I think is part of POPL 2024. I intend to add more effects features based on the Doo-Bee-Doo-Bee-Doo paper by Conor McBride and others; we&#39;ll see how far I get.\n\nThis kind of library is not how Gleam does things, as a language. I wrote it for fun. You should be a pretty big fan of control effects before attempting to build a serious project with `fluoresce`!\n\n```sh\ngleam add fluoresce\n```\n```gleam\nimport fluoresce\n\npub fn main() {\n  // TODO: An example of the project in use\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/fluoresce&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"fluoresce","title":"Cont","content":"pub type Cont(r, a) {\n  Cont(run: fn(fn(a) -&gt; r) -&gt; r)\n}\n\nCont(run: fn(fn(a) -&gt; r) -&gt; r)\n\n\nSynonyms:\nfluoresce.Cont\nfluoresce Cont","url":"fluoresce.html#Cont"},{"doc":"fluoresce","title":"Not","content":"pub type Not(r, a) =\n  fn(a) -&gt; r\n\n\nSynonyms:\nfluoresce.Not\nfluoresce Not","url":"fluoresce.html#Not"},{"doc":"fluoresce","title":"Subtract","content":"pub type Subtract(r, a, b) =\n  #(a, Not(r, b))\n\n\nSynonyms:\nfluoresce.Subtract\nfluoresce Subtract","url":"fluoresce.html#Subtract"},{"doc":"fluoresce","title":"apply","content":"pub fn apply(\n  e: Cont(a, Result(b, c)),\n  not_a: fn(c) -&gt; a,\n) -&gt; Cont(a, b)\n\nSynonyms:\nfluoresce.apply\nfluoresce apply","url":"fluoresce.html#apply"},{"doc":"fluoresce","title":"bind","content":"pub fn bind(c: Cont(a, b), f: fn(b) -&gt; Cont(a, c)) -&gt; Cont(a, c)\n\nSynonyms:\nfluoresce.bind\nfluoresce bind","url":"fluoresce.html#bind"},{"doc":"fluoresce","title":"callcc","content":"pub fn callcc(f: fn(fn(a) -&gt; b) -&gt; a) -&gt; Cont(b, a)\n\nSynonyms:\nfluoresce.callcc\nfluoresce callcc","url":"fluoresce.html#callcc"},{"doc":"fluoresce","title":"co","content":"pub fn co(\n  f: fn(fn(a) -&gt; b) -&gt; Cont(b, c),\n  rest: fn(Result(c, a)) -&gt; Cont(b, d),\n) -&gt; Cont(b, d)\n\nSynonyms:\nfluoresce.co\nfluoresce co","url":"fluoresce.html#co"},{"doc":"fluoresce","title":"join","content":"pub fn join(a: Cont(a, Cont(a, b))) -&gt; Cont(a, b)\n\nSynonyms:\nfluoresce.join\nfluoresce join","url":"fluoresce.html#join"},{"doc":"fluoresce","title":"throw","content":"pub fn throw(a: a, not_a: fn(a) -&gt; b) -&gt; Cont(b, c)\n\nSynonyms:\nfluoresce.throw\nfluoresce throw","url":"fluoresce.html#throw"},{"doc":"fluoresce","title":"wrap","content":"pub fn wrap(a: a) -&gt; Cont(b, a)\n\nSynonyms:\nfluoresce.wrap\nfluoresce wrap","url":"fluoresce.html#wrap"},{"doc":"fluoresce","title":"fluoresce","content":"","url":"fluoresce.html"},{"doc":"logic","title":"adjunction","content":"pub fn adjunction(\n  f: fn(fn(a) -&gt; b) -&gt; Cont(b, c),\n) -&gt; Cont(b, fn(fn(c) -&gt; b) -&gt; Cont(b, a))\n\nSynonyms:\nlogic.adjunction\nlogic adjunction","url":"logic.html#adjunction"},{"doc":"logic","title":"coexponential_to_function","content":"pub fn coexponential_to_function(\n  c: fn(#(a, fn(b) -&gt; c)) -&gt; c,\n) -&gt; Cont(c, fn(a) -&gt; Cont(c, b))\n\nSynonyms:\nlogic.coexponential_to_function\nlogic coexponential_to_function","url":"logic.html#coexponential_to_function"},{"doc":"logic","title":"contramap","content":"pub fn contramap(\n  not_b: fn(a) -&gt; b,\n  f: fn(c) -&gt; Cont(b, a),\n) -&gt; Cont(b, fn(c) -&gt; b)\n\nSynonyms:\nlogic.contramap\nlogic contramap","url":"logic.html#contramap"},{"doc":"logic","title":"de_morgan_1","content":"pub fn de_morgan_1(\n  x: fn(Result(a, b)) -&gt; c,\n) -&gt; Cont(c, #(fn(b) -&gt; c, fn(a) -&gt; c))\n\nSynonyms:\nlogic.de_morgan_1\nlogic de_morgan_1","url":"logic.html#de_morgan_1"},{"doc":"logic","title":"de_morgan_2","content":"pub fn de_morgan_2(\n  x: #(fn(a) -&gt; b, fn(c) -&gt; b),\n) -&gt; Cont(b, fn(Result(c, a)) -&gt; b)\n\nSynonyms:\nlogic.de_morgan_2\nlogic de_morgan_2","url":"logic.html#de_morgan_2"},{"doc":"logic","title":"de_morgan_3","content":"pub fn de_morgan_3(\n  x: fn(#(a, b)) -&gt; c,\n) -&gt; Cont(c, Result(fn(b) -&gt; c, fn(a) -&gt; c))\n\nSynonyms:\nlogic.de_morgan_3\nlogic de_morgan_3","url":"logic.html#de_morgan_3"},{"doc":"logic","title":"de_morgan_4","content":"pub fn de_morgan_4(\n  x: Result(fn(a) -&gt; b, fn(c) -&gt; b),\n) -&gt; Cont(b, fn(#(c, a)) -&gt; b)\n\nSynonyms:\nlogic.de_morgan_4\nlogic de_morgan_4","url":"logic.html#de_morgan_4"},{"doc":"logic","title":"disjunctive_syllogism","content":"pub fn disjunctive_syllogism(\n  e: Cont(a, Result(b, c)),\n  not_a: fn(c) -&gt; a,\n) -&gt; Cont(a, b)\n\nSynonyms:\nlogic.disjunctive_syllogism\nlogic disjunctive_syllogism","url":"logic.html#disjunctive_syllogism"},{"doc":"logic","title":"double_negate","content":"pub fn double_negate(a: a) -&gt; Cont(b, fn(fn(a) -&gt; b) -&gt; b)\n\nSynonyms:\nlogic.double_negate\nlogic double_negate","url":"logic.html#double_negate"},{"doc":"logic","title":"double_negation_elimination","content":"pub fn double_negation_elimination(\n  not_not_a: fn(fn(a) -&gt; b) -&gt; b,\n) -&gt; Cont(b, a)\n\nSynonyms:\nlogic.double_negation_elimination\nlogic double_negation_elimination","url":"logic.html#double_negation_elimination"},{"doc":"logic","title":"excluded_middle","content":"pub fn excluded_middle() -&gt; Cont(a, Result(fn(b) -&gt; a, b))\n\nSynonyms:\nlogic.excluded_middle\nlogic excluded_middle","url":"logic.html#excluded_middle"},{"doc":"logic","title":"function_to_coexponential","content":"pub fn function_to_coexponential(\n  f: fn(a) -&gt; Cont(b, c),\n) -&gt; Cont(b, fn(#(a, fn(c) -&gt; b)) -&gt; b)\n\nSynonyms:\nlogic.function_to_coexponential\nlogic function_to_coexponential","url":"logic.html#function_to_coexponential"},{"doc":"logic","title":"implies","content":"pub fn implies(\n  f: fn(a) -&gt; Cont(b, c),\n) -&gt; Cont(b, Result(c, fn(a) -&gt; b))\n\nSynonyms:\nlogic.implies\nlogic implies","url":"logic.html#implies"},{"doc":"logic","title":"modus_ponens","content":"pub fn modus_ponens(f: Result(a, fn(b) -&gt; c), a: b) -&gt; Cont(c, a)\n\nSynonyms:\nlogic.modus_ponens\nlogic modus_ponens","url":"logic.html#modus_ponens"},{"doc":"logic","title":"pierces_law","content":"pub fn pierces_law(\n  f: fn(fn(a) -&gt; Cont(b, c)) -&gt; Cont(b, a),\n) -&gt; Cont(b, a)\n\nSynonyms:\nlogic.pierces_law\nlogic pierces_law","url":"logic.html#pierces_law"},{"doc":"logic","title":"logic","content":"","url":"logic.html"}]);